@@ -22,7 +22,7 @@ from plotly import tools as tls
 from sklearn.model_selection import ParameterGrid
 import copy
 
-from .dashboard.Dashboard import AgentDashboard as AgentDashboard
+from .dashboard.Dashboard import AgentDashboard
 from .streams import DataStreamMET4FOF
 
 from .develop.ML_Experiment import save_experiment
@@ -32,7 +32,7 @@ class AgentMET4FOF(Agent):
     """
     Base class for all agents with specific functions to be overridden/supplied by user.
 
-    Behavioural functions for users to provide are init_parameters, agent_loop and on_received_message.
+    Behavioral functions for users to provide are init_parameters, agent_loop and on_received_message.
     Communicative functions are bind_output, unbind_output and send_output.
 
     """
@@ -80,7 +80,7 @@ class AgentMET4FOF(Agent):
         self.PubAddr = self.bind('PUB', alias=self.PubAddr_alias,transport='tcp')
         self.AgentType = type(self).__name__
         self.log_info("INITIALIZED")
-        # These are the available states to change the agents' behaviour in
+        # These are the available states to change the agents' behavior in
         # agent_loop.
         self.states = {0: "Idle", 1: "Running", 2: "Pause", 3: "Stop", 4: "Reset"}
         self.current_state = self.states[0]
@@ -92,7 +92,7 @@ class AgentMET4FOF(Agent):
 
         try:
             self.init_parameters()
-        except Exception as e:
+        except Exception:
             return 0
 
     def reset(self):
@@ -137,7 +137,7 @@ class AgentMET4FOF(Agent):
             if self.log_mode:
                 super().log_info(message)
 
-        except Exception as e:
+        except Exception:
                 return -1
 
     def init_agent_loop(self, loop_wait: Optional[int] = 1.0):
@@ -153,7 +153,7 @@ class AgentMET4FOF(Agent):
         """
         self.loop_wait = loop_wait
         self.stop_all_timers()
-        #check if agent_loop is overriden by user
+        # check if agent_loop is overridden by user
         if self.__class__.agent_loop == AgentMET4FOF.agent_loop:
             return 0
         else:
@@ -335,7 +335,7 @@ class AgentMET4FOF(Agent):
 
         # process the received data here
         start_time_pack = time.time()
-        proc_msg = self.on_received_message(message)
+        self.on_received_message(message)
         end_time_pack = time.time()
         self.log_info("Tproc: "+str(round(end_time_pack-start_time_pack,6)))
 
@@ -1440,8 +1440,8 @@ class _Logger(AgentMET4FOF):
         self.save_log_info(str(message))
 
     def save_log_info(self, log_msg):
-        re_sq = '\[(.*?)\]'
-        re_rd = '\((.*?)\)'
+        re_sq = r'\[(.*?)\]'
+        re_rd = r'\((.*?)\)'
 
         date = re.findall(re_sq,log_msg)[0]
         date = "[" + date + "]"
