@@ -2,8 +2,9 @@ import dash
 import dash_cytoscape as cyto
 import dash_html_components as html
 import dash_core_components as dcc
-import agentMET4FOF.dashboard.LayoutHelper as LayoutHelper
-from agentMET4FOF.dashboard.LayoutHelper import create_nodes_cytoscape, create_edges_cytoscape, create_monitor_graph
+from . import LayoutHelper
+from .LayoutHelper import create_nodes_cytoscape, create_edges_cytoscape, \
+    create_monitor_graph
 from dash.exceptions import PreventUpdate
 import networkx as nx
 
@@ -376,6 +377,19 @@ def prepare_agt_net_callbacks(app):
         # monitor_graphs = monitor_graphs+ [{'displayModeBar': False, 'editable': False, 'scrollZoom':False}]
         return monitor_graphs+ style_graphs
 
+    def _handle_matplotlib_figure(input_data, from_agent_name: str):
+        """
+        Internal function. Checks the mode of matplotlib.figure.Fig to be plotted
+        Either it is a base64 str image, or a plotly graph
+
+        This is used in plotting the received matplotlib figures in the MonitorAgent's plot memory.
+        """
+
+        if isinstance(input_data, str):
+            new_graph = html.Img(src=input_data, title=from_agent_name)
+        else:
+            new_graph = dcc.Graph(figure=input_data)
+        return new_graph
     #load Monitors data and draw - all at once
     @app.callback([dash.dependencies.Output('matplotlib-division', 'children')],
                  [dash.dependencies.Input('interval-update-monitor-graph', 'n_intervals')])
@@ -413,15 +427,15 @@ def prepare_agt_net_callbacks(app):
             html_div_monitor.append(html.H5(agent_name, style={"text-align": "center"}))
             # create a new graph for every agent
             for from_agent_name in plot_data:
-                # get the 'data' relevant to 'monitor_agent_input'
-                input_data = plot_data[from_agent_name]
+                # get the graph relevant to 'monitor_agent_input'
+                graph = plot_data[from_agent_name]
 
-                if type(input_data).__name__ == 'dict':
-                    for key in input_data.keys():
-                        new_graph = html.Img(src=input_data[key], title=from_agent_name)
+                if isinstance(graph, dict):
+                    for graph_ in graph.values():
+                        new_graph = _handle_matplotlib_figure(graph_, from_agent_name)
                         html_div_monitor.append(new_graph)
                 else:
-                    new_graph = html.Img(src=input_data, title=from_agent_name)
+                    new_graph = _handle_matplotlib_figure(graph, from_agent_name)
                     html_div_monitor.append(new_graph)
 
             #only add the graph if there is some plots in the Monitor Agent
